@@ -279,6 +279,7 @@ def prescriptions(model, input_df, scored_df, actionable_fields, dv_description,
         else:
             increase_value = 1000
         
+    
         #Calculate change for increasing actionable values by jump amount
         if v in actionable_fields.keys():
             
@@ -336,7 +337,7 @@ def prescriptions(model, input_df, scored_df, actionable_fields, dv_description,
             del input_decrease, input_change_prob
         
         #For all non-actionable features, determine how the records value is contributing to its score
-        #Score all scores when the feature is set to 0. Will compare it to the actual score after the join
+        #Score when the feature is set to 0. Will compare it to the actual score after the join
         
         input_zero = input_df.copy(deep=True)
 
@@ -355,7 +356,7 @@ def prescriptions(model, input_df, scored_df, actionable_fields, dv_description,
         input_change_prob = pd.concat([input_change_prob, feature_value], axis=1)
 
         change_score = pd.concat([change_score, input_change_prob], axis = 0)
-            
+                
         del input_zero, input_change_prob
             
     #display(change_score)
@@ -382,12 +383,19 @@ def prescriptions(model, input_df, scored_df, actionable_fields, dv_description,
     change_score = change_score[(change_score['effect'] > 0.001) | (change_score['type'] != 'actionable')]
     
     #For Expainable items, determine directionality
-    change_score['direction'] = np.where((change_score['type'] == 'explainable') & (change_score['effect'] < 0),
-                                         'decreases',
-                                         np.where((change_score['type'] == 'explainable') & (change_score['effect'] > 0),
-                                                  'increases',
-                                                  change_score['direction']
-                                        ))
+    if len(actionable_fields) == 0:
+        change_score['direction'] = np.where((change_score['type'] == 'explainable') & (change_score['effect'] < 0),
+                                             'decreases',
+                                             'increases'
+                                            )
+         
+    else:
+        change_score['direction'] = np.where((change_score['type'] == 'explainable') & (change_score['effect'] < 0),
+                                             'decreases',
+                                             np.where((change_score['type'] == 'explainable') & (change_score['effect'] > 0),
+                                                      'increases',
+                                                       change_score['direction']
+                                            ))
         
     #Calc abs of effect to be used for sorting
     change_score['effect_pct_abs'] = change_score['effect_pct'].abs()
@@ -398,7 +406,6 @@ def prescriptions(model, input_df, scored_df, actionable_fields, dv_description,
     #Sort by index (asc), type (asc), absoulte value of effect (desc)
     change_score.sort_values(by=[change_score.index.name, 'type', 'effect_pct_abs'], axis=0, ascending=(True, True, False), inplace=True)
     
-    #Add on Feature Labels
     #Add on Feature Labels
     if field_labels:
         change_score['feature_label'] = change_score['feature'].map(field_labels)
@@ -412,16 +419,23 @@ def prescriptions(model, input_df, scored_df, actionable_fields, dv_description,
         
     
     #Zero fill missing values so insights will format numbers properly due to no missing values
-    change_score['increase_value'] = change_score['increase_value'].fillna(0)
+    if 'increase_value' in change_score.columns: 
+        change_score['increase_value'] = change_score['increase_value'].fillna(0)
+        
     change_score['feature_value'] = change_score['feature_value'].fillna(0)
     
     
     #Add insight text
-    #For Actionable Features    
-    change_score['insight'] = np.where((change_score['binary'] == False) & (change_score['type'] == 'actionable'),
-                                       change_score['direction']+" \'"+change_score['feature_label']+"\' by "+np.where(change_score['increase_value'] >= 1, change_score['increase_value'].astype(int).astype(str), change_score['increase_value'].astype(str))+f" will increase {dv_description} by "+np.where(change_score['effect_pct'] > 1, np.round((change_score['effect_pct']+1),1).astype(str)+"%.", np.round(change_score['effect_pct']*100,0).astype(int).astype(str)+"%."), #For non-binary
-                                       "Changing the value of \'"+change_score['feature_label']+"\' to "+np.where(change_score['direction']=='Increasing', '\'Yes\'', '\'No\'')+f" will increase {dv_description} by "+np.where(change_score['effect_pct'] > 1, np.round((change_score['effect_pct']+1),1).astype(str)+"x.", np.round(change_score['effect_pct']*100,0).astype(int).astype(str)+"%.") #For binary 
-                                       )     
+    #If not actionable fields, create empty insight field
+    if len(actionable_fields) == 0:
+        change_score['insight'] = np.nan
+    
+    #For Actionable Features  
+    if len(actionable_fields) > 0:
+        change_score['insight'] = np.where((change_score['binary'] == False) & (change_score['type'] == 'actionable'),
+                                           change_score['direction']+" \'"+change_score['feature_label']+"\' by "+np.where(change_score['increase_value'] >= 1, change_score['increase_value'].astype(int).astype(str), change_score['increase_value'].astype(str))+f" will increase {dv_description} by "+np.where(change_score['effect_pct'] > 1, np.round((change_score['effect_pct']+1),1).astype(str)+"%.", np.round(change_score['effect_pct']*100,0).astype(int).astype(str)+"%."), #For non-binary
+                                           "Changing the value of \'"+change_score['feature_label']+"\' to "+np.where(change_score['direction']=='Increasing', '\'Yes\'', '\'No\'')+f" will increase {dv_description} by "+np.where(change_score['effect_pct'] > 1, np.round((change_score['effect_pct']+1),1).astype(str)+"x.", np.round(change_score['effect_pct']*100,0).astype(int).astype(str)+"%.") #For binary 
+                                           )     
     
     #For Explainable (not-Actionable) Features
     change_score['insight'] = np.where((change_score['type'] == 'explainable') & (change_score['binary'] == False),
