@@ -1,4 +1,4 @@
-def model_metrics(model, x_train, y_train, x_test, y_test, show_graphs='Y', f_score = 0.50, classification = 'Y', algo=None):
+def model_metrics(model, x_train, y_train, x_test, y_test, show_graphs=True, f_score = 0.50, classification = True, algo=None):
     
     """
     Display a variety of model metrics for linear and logistic predictive models.
@@ -32,14 +32,14 @@ def model_metrics(model, x_train, y_train, x_test, y_test, show_graphs='Y', f_sc
 
         # mean absolute value of the SHAP values
         print('Feature Importance')
-        shap.plots.bar(shap_values)
+        shap.plots.bar(shap_values, max_display=20)
 
         # visualize the first prediction's explanation
         #believe this is the log-likelihood. Would need to exp()
-        shap.plots.waterfall(shap_values[0])
+        shap.plots.waterfall(shap_values[0], max_display=20)
 
         # visualize the first prediction's explanation with a force plot
-        shap.plots.beeswarm(shap_values)
+        shap.plots.beeswarm(shap_values, max_display=20)
        
         # Assign shap values based on test dataset
         shap_values = explainer.shap_values(x_test)
@@ -53,13 +53,13 @@ def model_metrics(model, x_train, y_train, x_test, y_test, show_graphs='Y', f_sc
 
         result = pd.concat([features, importance], axis=1)
         result.columns = ['features', 'importance']
-        top20_features = result.sort_values(by=['importance'], ascending=False).head(20)
-        display(top20_features)
+        features = result.sort_values(by=['importance'], ascending=False).head(20)
+        display(features)
 
 
         sns.set_theme(style="whitegrid")
         sns.set(rc={'figure.figsize':(11,8)})
-        ax = sns.barplot(x="features", y="importance", data=top20_features)
+        ax = sns.barplot(x="features", y="importance", data=features)
         ax.set_xticklabels(ax.get_xticklabels(), rotation=45, ha="right")
         ax.set(title = "Top 20 features for account expansion")
    
@@ -225,12 +225,12 @@ def model_metrics(model, x_train, y_train, x_test, y_test, show_graphs='Y', f_sc
         import seaborn as seaborn
         
         # ROC
-        metrics.plot_roc_curve(model, x_test, y_test)  
+        metrics.RocCurveDisplay.from_estimator(model, x_test, y_test)  
         plt.title('ROC')
-        plt.show() 
-        
+        plt.show()
+    
         # Precision vs Recall
-        metrics.plot_precision_recall_curve(model, x_test, y_test)
+        metrics.PrecisionRecallDisplay.from_estimator(model, x_test, y_test)
         plt.title('2-class Precision-Recall curve')
         plt.show()
 
@@ -298,7 +298,7 @@ def model_metrics(model, x_train, y_train, x_test, y_test, show_graphs='Y', f_sc
             warnings.warn("Lift cannot be calculated because model deciles do not exist!")
     
     if classification == True:
-        return metricx, lift, classification_metricx
+        return metricx, lift, classification_metricx, features
     
     else:
-        return metricx, lift
\ No newline at end of file
+        return metricx, lift, features
\ No newline at end of file
